package CPAN::Smoke::Author;

use strict;
use vars qw($VERSION @ISA);

$VERSION = 0.01;

use Carp::Assert;
use CLASS;

require Class::Accessor;
@ISA = qw(Class::Accessor);

CLASS->mk_accessors(qw(id dir email name _modules));


=head1 NAME

CPAN::Smoke::Author - representations of CPAN authors

=head1 SYNOPSIS

  use CPAN::Smoke::Author;

  my $author = CPAN::Smoke::Author->create(\%author_data);

  $author->add_modules(@modules);
  my @modules = $author->modules;

  # Simple accessors
  $author->id;
  $author->dir;
  $author->email;
  $author->name;

=head1 DESCRIPTION

A representation of CPAN authors for the purposes of smoking.


=head2 Constructors

=over 4

=item B<create>

  my $author = CPAN::Smoke::Author->create(\%author_data);

Creates a new author object with the given data.

=cut

sub create {
    my($class, $data) = @_;

    # Take a guess at the author's directory.
    if( defined $data->{id} && !defined $data->{dir} ) {
        my($second, $first) = $data->{id} =~ /^((.).)/;
        $data->{dir} = "$first/$second/$data->{id}";
    }

    my $author = $class->SUPER::new($data);

    $author->_modules([]);

    return $author;
}

=back


=head2 Modules

=over 4

=item B<modules>

  my @modules = $author->modules;

Returns a list of modules written by this author as CPAN::Module
objects.

=cut

sub modules {
    my($self) = shift;

    return @{$self->_modules};
}

=item B<add_modules>

  $author->add_modules(@modules);

Addeds a bunch of CPAN::Module to the list of modules written by this
author.

=cut

sub add_modules {
    my($self, @modules) = @_;

    assert( !grep(!$_->isa('CPAN::Smoke::Module'), @modules) ) if DEBUG;

    my $curr_modules = $self->_modules();
    push @$curr_modules, @modules;

    return 1;
}

=back


=head2 Accessors

These can be used to both get and set.

=over 4

=item B<id>

  my $id = $author->id;

The author's CPAN ID.

=item B<dir>

  my $dir = $author->dir;

The directory in CPAN which the author's modules reside in.  Normally
prepended with "modules/by-authors/id/"

=item B<email>

  my $email = $author->email;

The author's email address.

=item B<name>

  my $name = $author->name;

Real name of the author.

=back

=head1 AUTHOR

Michael G Schwern E<lt>schwern@pobox.comE<gt>

=head1 SEE ALSO

CPAN::Smoke, CPAN::Smoke::Module

=cut


1;
